"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const slugify_1 = require("slugify");
const shell = require('shelljs');
class New extends command_1.Command {
    async run() {
        /**
         * Welcome
         */
        this.log('\n🌍 Welcome to the Blitz CLI\n');
        this.log('Before starting ensure you have completed the following..');
        this.log('- SSH Keys have been added to your Github account');
        this.log('- Have created a stack in Contentstack for your project');
        this.log('- Have access to the Contentstack API Key and Access Token');
        const confirm = await cli_ux_1.default.confirm('\nReady to go? (y/n)');
        if (!confirm)
            shell.exit(1);
        /**
         * Prompt for all user input
         */
        const projectName = await cli_ux_1.default.prompt("What is the name of the name of this project? Eg 'Berlitz DE'");
        const defaultSlug = slugify_1.default(projectName, { lower: true });
        const projectSlug = await cli_ux_1.default.prompt(`What is the name of the repository? Eg '${defaultSlug}'`, {
            default: defaultSlug,
        });
        const contentStackApiKey = await cli_ux_1.default.prompt("What is your project's Contentstack API Key? (can be found via Settings > Stack)");
        const contentStackAccessToken = await cli_ux_1.default.prompt("What is your project's Contentstack Access Token? (can be found via Settings > Stack)");
        /**
         * Check if directory exists, bail out if it does
         */
        if (shell.exec(`[ -d ${projectSlug} ]`).code === 0) {
            shell.echo(`\n❌ A directory named '${projectSlug}' already exists, exiting installer..\n`);
            shell.exit(1);
        }
        /**
         * Check dependencies needed for the script
         * git, brew, brew hub
         */
        shell.echo('\n');
        // git
        if (!shell.which('git')) {
            shell.echo('❌ Sorry, this script requires git');
            shell.exit(1);
        }
        else {
            shell.echo('✅ git is installed');
        }
        // brew
        if (!shell.which('brew')) {
            shell.echo('🚧 brew is not installed, installing...');
            shell.exec('/usr/bin/ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"');
        }
        else {
            shell.echo('✅ brew is installed');
        }
        // brew hub
        const brewHubTest = shell.exec('brew ls --versions hub > /dev/null');
        if (brewHubTest.code !== 0) {
            shell.echo('🚧 hub not installed, installing...');
            shell.exec('brew install hub');
        }
        else {
            shell.echo('✅ brew hub is installed');
        }
        /**
         * Check repository doesn't already exist
         */
        if (shell.exec(`git ls-remote https://github.com/berlitz-global/${projectSlug} -q`, { silent: true }).code !== 128) {
            shell.echo(`\n❌ Sorry, it looks like the repository https://github.com/berlitz-global/${projectSlug} already exists\n`);
            shell.exit(1);
        }
        else {
            shell.echo(`✅ https://github.com/berlitz-global/${projectSlug} is available`);
        }
        /**
         * All good, let's clone the boiler plate and get started
         */
        shell.echo('🚚 Cloning latest blitz-boilerplate...');
        shell.exec(`git clone git@github.com:berlitz-global/blitz-boilerplate.git ${projectSlug}`);
        shell.cd(projectSlug);
        shell.rm('-rf', '.git');
        // create an .env file
        shell.exec('touch .env.staging');
        shell.exec(`echo CONTENTSTACK_API_KEY=${contentStackApiKey} >> .env.staging\n`);
        shell.exec(`echo CONTENTSTACK_ACCESS_TOKEN=${contentStackAccessToken} >> .env.staging\n`);
        shell.exec(`echo CONTENTSTACK_ENVIRONMENT=staging >> .env.staging\n`);
        // replace blitz-template vars
        shell.exec(`sed -i '' -e 's/blitz-template-name/${projectName}/g' package.json`);
        shell.exec(`sed -i '' -e 's/blitz-template-slug/${projectSlug}/g' package.json`);
        shell.exec(`sed -i '' -e 's/blitz-template-name/${projectName}/g' README.md`);
        shell.exec(`sed -i '' -e 's/blitz-template-name/${projectName}/g' gatsby-config.js`);
        // add to git
        shell.exec('git init');
        shell.exec('git add --all');
        shell.exec('git commit -m "initial commit, clone blitz-boilerplate"');
        shell.exec(`hub create -p berlitz-global/${projectSlug}`);
        shell.exec(`git remote set-url origin git@github.com:berlitz-global/${projectSlug}.git`);
        shell.exec('git push origin master');
        shell.echo(`\n🎉 Repository successfully created and pushed to\n👉 https://github.com/berlitz-global/${projectSlug} \n`);
        await cli_ux_1.default.open(`https://github.com/berlitz-global/${projectSlug}`);
    }
}
New.description = 'describe the command here';
exports.default = New;
